@@ -1,4 +1,7 @@
 #!/bin/which python3
+
+# fmt: off
+
 import pathlib
 import sys
 import os
@@ -11,7 +14,7 @@ import mimetypes
 
 import grpc
 from argparse import ArgumentParser, Namespace
-from typing import Dict, Generator, List, Union, Any, Sequence, Tuple
+from typing import Dict, Generator, List, Optional, Union, Any, Sequence, Tuple
 from dotenv import load_dotenv
 from google.protobuf.json_format import MessageToJson
 from PIL import Image
@@ -39,29 +42,27 @@ algorithms: Dict[str, int] = {
     "k_lms": generation.SAMPLER_K_LMS,
 }
 
-def image_to_prompt(im, init: bool = False, mask: bool = False) -> Tuple[str, generation.Prompt]:
+
+def image_to_prompt(im, init: bool = False, mask: bool = False) -> generation.Prompt:
     if init and mask:
         raise ValueError("init and mask cannot both be True")
     buf = io.BytesIO()
-    im.save(buf, format='PNG')
+    im.save(buf, format="PNG")
     buf.seek(0)
     if mask:
         return generation.Prompt(
             artifact=generation.Artifact(
-                type=generation.ARTIFACT_MASK,
-                binary=buf.getvalue()
+                type=generation.ARTIFACT_MASK, binary=buf.getvalue()
             )
         )
     return generation.Prompt(
         artifact=generation.Artifact(
-            type=generation.ARTIFACT_IMAGE,
-            binary=buf.getvalue()
-        ),
-        parameters=generation.PromptParameters(
-            init=init
+            type=generation.ARTIFACT_IMAGE, binary=buf.getvalue()
         ),
+        parameters=generation.PromptParameters(init=init),
     )
 
+
 def get_sampler_from_str(s: str) -> generation.DiffusionSampler:
     """
     Convert a string to a DiffusionSampler enum.
@@ -118,7 +119,7 @@ def process_artifacts_from_answers(
                         artifact_t = generation.ArtifactType.Name(artifact.type)
                         logger.info(f"wrote {artifact_t} to {out_p}")
 
-            yield [out_p, artifact]
+            yield (out_p, artifact)
             idx += 1
 
 
@@ -144,7 +145,7 @@ def open_images(
                 logger.info(f"opening {path}")
             img = Image.open(io.BytesIO(artifact.binary))
             img.show()
-        yield [path, artifact]
+        yield (path, artifact)
 
 
 class StabilityInference:
@@ -178,8 +179,7 @@ class StabilityInference:
 
         if host.endswith("443"):
             if key:
-                call_credentials.append(
-                    grpc.access_token_call_credentials(f"{key}"))
+                call_credentials.append(grpc.access_token_call_credentials(f"{key}"))
             else:
                 raise ValueError(f"key is required for {host}")
             channel_credentials = grpc.composite_channel_credentials(
@@ -200,8 +200,8 @@ class StabilityInference:
     def generate(
         self,
         prompt: Union[List[str], str],
-        init_image: Image.Image = None,
-        mask_image: Image.Image = None,
+        init_image: Optional[Image.Image] = None,
+        mask_image: Optional[Image.Image] = None,
         height: int = 512,
         width: int = 512,
         start_schedule: float = 1.0,
@@ -212,7 +212,7 @@ class StabilityInference:
         seed: Union[Sequence[int], int] = 0,
         samples: int = 1,
         safety: bool = True,
-        classifiers: generation.ClassifierParameters = None,
+        classifiers: Optional[generation.ClassifierParameters] = None,
     ) -> Generator[generation.Answer, None, None]:
         """
         Generate images from a prompt.
@@ -229,36 +229,39 @@ class StabilityInference:
         :param steps: Number of steps to take.
         :param seed: Seed for the random number generator.
         :param samples: Number of samples to generate.
-        :param safety: Whether to use safety mode.
-        :param classifiers: Classifier parameters to use.
+        :param safety: DEPRECATED/UNUSED - Cannot be disabled.
+        :param classifiers: DEPRECATED/UNUSED - Has no effect on image generation.
         :return: Generator of Answer objects.
         """
-        if safety and classifiers is None:
-            classifiers = generation.ClassifierParameters()
-
         if (prompt is None) and (init_image is None):
             raise ValueError("prompt and/or init_image must be provided")
 
         if (mask_image is not None) and (init_image is None):
-            raise ValueError("If mask_image is provided, init_image must also be provided")
+            raise ValueError(
+                "If mask_image is provided, init_image must also be provided"
+            )
 
         request_id = str(uuid.uuid4())
 
         if not seed:
             seed = [random.randrange(0, 4294967295)]
-        else:
+        elif isinstance(seed, int):
             seed = [seed]
+        else:
+            seed = list(seed)
 
+        prompt_ = []
         if isinstance(prompt, str):
-            prompt = [generation.Prompt(text=prompt)]
+            prompt_ = [generation.Prompt(text=prompt)]
         elif isinstance(prompt, Sequence):
-            prompt = [generation.Prompt(text=p) for p in prompt]
+            prompt_ = [generation.Prompt(text=p) for p in prompt]
         else:
             raise TypeError("prompt must be a string or a sequence")
 
-        if (init_image is not None):
-            prompt += [image_to_prompt(init_image, init=True)]
-            parameters = generation.StepParameter(
+        if init_image is not None:
+            prompt_ += [image_to_prompt(init_image, init=True)]
+            parameters = (
+                generation.StepParameter(
                     scaled_step=0,
                     sampler=generation.SamplerParameters(
                         cfg_scale=cfg_scale,
@@ -266,21 +269,23 @@ class StabilityInference:
                     schedule=generation.ScheduleParameters(
                         start=start_schedule,
                         end=end_schedule,
-                    )
+                    ),
                 ),
-            if (mask_image is not None):
-                prompt += [image_to_prompt(mask_image, mask=True)]
+            )
+            if mask_image is not None:
+                prompt_ += [image_to_prompt(mask_image, mask=True)]
         else:
-            parameters = generation.StepParameter(
+            parameters = (
+                generation.StepParameter(
                     scaled_step=0,
-                    sampler=generation.SamplerParameters(
-                        cfg_scale=cfg_scale),
+                    sampler=generation.SamplerParameters(cfg_scale=cfg_scale),
                 ),
+            )
 
         rq = generation.Request(
             engine_id=self.engine,
             request_id=request_id,
-            prompt=prompt,
+            prompt=prompt_,
             image=generation.ImageParameters(
                 transform=generation.TransformType(diffusion=sampler),
                 height=height,
@@ -290,7 +295,6 @@ class StabilityInference:
                 samples=samples,
                 parameters=parameters,
             ),
-            classifier=classifiers,
         )
 
         if self.verbose:
@@ -311,8 +315,7 @@ class StabilityInference:
                     )
                 else:
                     logger.info(
-                        f"Got keepalive {answer.answer_id} in "
-                        f"{duration:0.2f}s"
+                        f"Got keepalive {answer.answer_id} in " f"{duration:0.2f}s"
                     )
 
             yield answer
@@ -372,11 +375,15 @@ if __name__ == "__main__":
     )
     parser.add_argument(
         "--start_schedule",
-        type=float, default=0.5, help="[0.5] start schedule for init image (must be greater than 0, 1 is full strength text prompt, no trace of image)"
+        type=float,
+        default=0.5,
+        help="[0.5] start schedule for init image (must be greater than 0, 1 is full strength text prompt, no trace of image)",
     )
     parser.add_argument(
         "--end_schedule",
-        type=float, default=0.01, help="[0.01] end schedule for init image"
+        type=float,
+        default=0.01,
+        help="[0.01] end schedule for init image",
     )
     parser.add_argument(
         "--cfg_scale", "-C", type=float, default=7.0, help="[7.0] CFG scale factor"
@@ -414,12 +421,14 @@ if __name__ == "__main__":
         default="stable-diffusion-v1-5",
     )
     parser.add_argument(
-        "--init_image", "-i",
+        "--init_image",
+        "-i",
         type=str,
         help="Init image",
     )
     parser.add_argument(
-        "--mask_image", "-m",
+        "--mask_image",
+        "-m",
         type=str,
         help="Mask image",
     )
@@ -432,10 +441,10 @@ if __name__ == "__main__":
         sys.exit(1)
     else:
         args.prompt = " ".join(args.prompt)
-        
+
     if args.init_image:
         args.init_image = Image.open(args.init_image)
-        
+
     if args.mask_image:
         args.mask_image = Image.open(args.mask_image)
 
